@@ -1,6 +1,46 @@
 """
 PySTAC is a library for working with SpatioTemporal Asset Catalogs (STACs)
 """
+__all__ = [
+    "__version__",
+    "STACError",
+    "STACTypeError",
+    "DuplicateObjectKeyError",
+    "ExtensionAlreadyExistsError",
+    "ExtensionNotImplemented",
+    "ExtensionTypeError",
+    "RequiredPropertyMissing",
+    "STACValidationError",
+    "MediaType",
+    "RelType",
+    "StacIO",
+    "STACObject",
+    "STACObjectType",
+    "Link",
+    "HIERARCHICAL_LINKS",
+    "Catalog",
+    "CatalogType",
+    "Collection",
+    "Extent",
+    "SpatialExtent",
+    "TemporalExtent",
+    "Summaries",
+    "CommonMetadata",
+    "RangeSummary",
+    "Item",
+    "Asset",
+    "ItemCollection",
+    "Provider",
+    "ProviderRole",
+    "read_file",
+    "read_dict",
+    "write_file",
+    "get_stac_version",
+    "set_stac_version",
+]
+
+import os
+from typing import Any, AnyStr, Dict, Optional, Union
 
 from pystac.errors import (
     STACError,
@@ -13,7 +53,6 @@ from pystac.errors import (
     STACValidationError,
 )
 
-from typing import Any, Dict, Optional
 from pystac.version import (
     __version__,
     get_stac_version,
@@ -23,18 +62,18 @@ from pystac.media_type import MediaType
 from pystac.rel_type import RelType
 from pystac.stac_io import StacIO
 from pystac.stac_object import STACObject, STACObjectType
-from pystac.link import Link, HIERARCHICAL_LINKS
+from pystac.link import Link, HIERARCHICAL_LINKS, HREF
 from pystac.catalog import Catalog, CatalogType
 from pystac.collection import (
     Collection,
     Extent,
     SpatialExtent,
     TemporalExtent,
-    Summaries,
 )
 from pystac.common_metadata import CommonMetadata
-from pystac.summaries import RangeSummary
-from pystac.item import Item, Asset
+from pystac.summaries import RangeSummary, Summaries
+from pystac.asset import Asset
+from pystac.item import Item
 from pystac.item_collection import ItemCollection
 from pystac.provider import ProviderRole, Provider
 import pystac.validation
@@ -50,6 +89,8 @@ import pystac.extensions.projection
 import pystac.extensions.sar
 import pystac.extensions.sat
 import pystac.extensions.scientific
+import pystac.extensions.storage
+import pystac.extensions.table
 import pystac.extensions.timestamps
 import pystac.extensions.version
 import pystac.extensions.view
@@ -66,6 +107,8 @@ EXTENSION_HOOKS = pystac.extensions.hooks.RegisteredExtensionHooks(
         pystac.extensions.sar.SAR_EXTENSION_HOOKS,
         pystac.extensions.sat.SAT_EXTENSION_HOOKS,
         pystac.extensions.scientific.SCIENTIFIC_EXTENSION_HOOKS,
+        pystac.extensions.storage.STORAGE_EXTENSION_HOOKS,
+        pystac.extensions.table.TABLE_EXTENSION_HOOKS,
         pystac.extensions.timestamps.TIMESTAMPS_EXTENSION_HOOKS,
         pystac.extensions.version.VERSION_EXTENSION_HOOKS,
         pystac.extensions.view.VIEW_EXTENSION_HOOKS,
@@ -73,7 +116,7 @@ EXTENSION_HOOKS = pystac.extensions.hooks.RegisteredExtensionHooks(
 )
 
 
-def read_file(href: str, stac_io: Optional[StacIO] = None) -> STACObject:
+def read_file(href: HREF, stac_io: Optional[StacIO] = None) -> STACObject:
     """Reads a STAC object from a file.
 
     This method will return either a Catalog, a Collection, or an Item based on what
@@ -105,7 +148,7 @@ def read_file(href: str, stac_io: Optional[StacIO] = None) -> STACObject:
 def write_file(
     obj: STACObject,
     include_self_link: bool = True,
-    dest_href: Optional[str] = None,
+    dest_href: Optional[HREF] = None,
     stac_io: Optional[StacIO] = None,
 ) -> None:
     """Writes a STACObject to a file.
@@ -131,6 +174,7 @@ def write_file(
     """
     if stac_io is None:
         stac_io = StacIO.default()
+    dest_href = None if dest_href is None else str(os.fspath(dest_href))
     obj.save_object(
         include_self_link=include_self_link, dest_href=dest_href, stac_io=stac_io
     )
