@@ -1,6 +1,9 @@
+from html import escape
 from copy import deepcopy
 from datetime import datetime
+
 from pystac.errors import STACTypeError
+from pystac.html.jinja_env import get_jinja_env
 from typing import (
     Any,
     Dict,
@@ -14,7 +17,6 @@ from typing import (
     cast,
 )
 
-import dateutil.parser
 from dateutil import tz
 
 import pystac
@@ -23,7 +25,8 @@ from pystac.asset import Asset
 from pystac.catalog import Catalog
 from pystac.layout import HrefLayoutStrategy
 from pystac.link import Link
-from pystac.utils import datetime_to_str
+from pystac.provider import Provider
+from pystac.utils import datetime_to_str, str_to_datetime
 from pystac.serialization import (
     identify_stac_object_type,
     identify_stac_object,
@@ -36,6 +39,10 @@ if TYPE_CHECKING:
     from pystac.provider import Provider as Provider_Type
 
 T = TypeVar("T")
+TemporalIntervals = Union[List[List[datetime]], List[List[Optional[datetime]]]]
+TemporalIntervalsLike = Union[
+    TemporalIntervals, List[datetime], List[Optional[datetime]]
+]
 
 
 class SpatialExtent:
@@ -175,7 +182,7 @@ class TemporalExtent:
         Datetimes are required to be in UTC.
     """
 
-    intervals: List[List[Optional[datetime]]]
+    intervals: TemporalIntervals
     """A list of two datetimes wrapped in a list,
     representing the temporal extent of a Collection. Open date ranges are
     represented by either the start (the first element of the interval) or the
@@ -187,16 +194,16 @@ class TemporalExtent:
 
     def __init__(
         self,
-        intervals: Union[List[List[Optional[datetime]]], List[Optional[datetime]]],
+        intervals: TemporalIntervals,
         extra_fields: Optional[Dict[str, Any]] = None,
     ):
         # A common mistake is to pass in a single interval instead of a
         # list of intervals. Account for this by transforming the input
         # in that case.
         if isinstance(intervals, list) and isinstance(intervals[0], datetime):
-            self.intervals = [cast(List[Optional[datetime]], intervals)]
+            self.intervals = intervals
         else:
-            self.intervals = cast(List[List[Optional[datetime]]], intervals)
+            self.intervals = intervals
 
         self.extra_fields = extra_fields or {}
 
@@ -245,9 +252,9 @@ class TemporalExtent:
             end = None
 
             if i[0]:
-                start = dateutil.parser.parse(i[0])
+                start = str_to_datetime(i[0])
             if i[1]:
-                end = dateutil.parser.parse(i[1])
+                end = str_to_datetime(i[1])
             parsed_intervals.append([start, end])
 
         return TemporalExtent(
@@ -416,7 +423,7 @@ class Collection(Catalog):
     Args:
         id : Identifier for the collection. Must be unique within the STAC.
         description : Detailed multi-line description to fully explain the
-            collection. `CommonMark 0.28 syntax <https://commonmark.org/>`_ MAY
+            collection. `CommonMark 0.29 syntax <https://commonmark.org/>`_ MAY
             be used for rich text representation.
         extent : Spatial and temporal extents that describe the bounds of
             all items contained within this Collection.
@@ -439,30 +446,47 @@ class Collection(Catalog):
             either a set of values or statistics such as a range.
         extra_fields : Extra fields that are part of the top-level
             JSON properties of the Collection.
-
-    Attributes:
-        id : Identifier for the collection.
-        description : Detailed multi-line description to fully explain the
-            collection.
-        extent : Spatial and temporal extents that describe the bounds of
-            all items contained within this Collection.
-        title : Optional short descriptive one-line title for the
-            collection.
-        stac_extensions : Optional list of extensions the Collection
-            implements.
-        keywords : Optional list of keywords describing the
-            collection.
-        providers : Optional list of providers of this
-            Collection.
-        assets : Optional map of Assets
-        summaries : An optional map of property summaries,
-            either a set of values or statistics such as a range.
-        links : A list of :class:`~pystac.Link` objects representing
-            all links associated with this Collection.
-        extra_fields : Extra fields that are part of the top-level
-            JSON properties of the Catalog.
+        assets : A dictionary mapping string keys to :class:`~pystac.Asset` objects. All
+            :class:`~pystac.Asset` values in the dictionary will have their
+            :attr:`~pystac.Asset.owner` attribute set to the created Collection.
     """
 
+    assets: Dict[str, Asset]
+    """Map of Assets"""
+
+    description: str
+    """Detailed multi-line description to fully explain the collection."""
+
+    extent: Extent
+    """Spatial and temporal extents that describe the bounds of all items contained
+    within this Collection."""
+
+    id: str
+    """Identifier for the collection."""
+
+    stac_extensions: List[str]
+    """List of extensions the Collection implements."""
+
+    title: Optional[str]
+    """Optional short descriptive one-line title for the collection."""
+
+    keywords: Optional[List[str]]
+    """Optional list of keywords describing the collection."""
+
+    providers: Optional[List[Provider]]
+    """Optional list of providers of this Collection."""
+
+    summaries: Summaries
+    """A map of property summaries, either a set of values or statistics such as a
+    range."""
+
+    links: List[Link]
+    """A list of :class:`~pystac.Link` objects representing all links associated with
+    this Collection."""
+
+    extra_fields: Dict[str, Any]
+    """Extra fields that are part of the top-level JSON properties of the Collection."""
+
     STAC_OBJECT_TYPE = STACObjectType.COLLECTION
 
     DEFAULT_FILE_NAME = "collection.json"
@@ -483,6 +507,7 @@ class Collection(Catalog):
         keywords: Optional[List[str]] = None,
         providers: Optional[List["Provider_Type"]] = None,
         summaries: Optional[Summaries] = None,
+        assets: Optional[Dict[str, Asset]] = None,
     ):
         super().__init__(
             id,
@@ -501,11 +526,22 @@ class Collection(Catalog):
         self.providers = providers
         self.summaries = summaries or Summaries.empty()
 
-        self.assets: Dict[str, Asset] = {}
+        self.assets = {}
+        if assets is not None:
+            for k, asset in assets.items():
+                self.add_asset(k, asset)
 
     def __repr__(self) -> str:
         return "<Collection id={}>".format(self.id)
 
+    def _repr_html_(self) -> str:
+        jinja_env = get_jinja_env()
+        if jinja_env:
+            template = jinja_env.get_template("Collection.jinja2")
+            return str(template.render(catalog=self))
+        else:
+            return escape(repr(self))
+
     def add_item(
         self,
         item: "Item_Type",
@@ -515,8 +551,12 @@ class Collection(Catalog):
         super().add_item(item, title, strategy)
         item.set_collection(self)
 
-    def to_dict(self, include_self_link: bool = True) -> Dict[str, Any]:
-        d = super().to_dict(include_self_link)
+    def to_dict(
+        self, include_self_link: bool = True, transform_hrefs: bool = True
+    ) -> Dict[str, Any]:
+        d = super().to_dict(
+            include_self_link=include_self_link, transform_hrefs=transform_hrefs
+        )
         d["extent"] = self.extent.to_dict()
         d["license"] = self.license
         if self.stac_extensions is not None:
@@ -539,13 +579,14 @@ class Collection(Catalog):
             description=self.description,
             extent=self.extent.clone(),
             title=self.title,
-            stac_extensions=self.stac_extensions,
-            extra_fields=self.extra_fields,
+            stac_extensions=self.stac_extensions.copy(),
+            extra_fields=deepcopy(self.extra_fields),
             catalog_type=self.catalog_type,
             license=self.license,
-            keywords=self.keywords,
-            providers=self.providers,
-            summaries=self.summaries,
+            keywords=self.keywords.copy() if self.keywords is not None else None,
+            providers=deepcopy(self.providers),
+            summaries=self.summaries.clone(),
+            assets={k: asset.clone() for k, asset in self.assets.items()},
         )
 
         clone._resolved_objects.cache(clone)
@@ -598,7 +639,9 @@ class Collection(Catalog):
         if summaries is not None:
             summaries = Summaries(summaries)
 
-        assets: Optional[Dict[str, Any]] = d.get("assets", None)
+        assets: Optional[Dict[str, Any]] = {
+            k: Asset.from_dict(v) for k, v in d.get("assets", {}).items()
+        }
         links = d.pop("links")
 
         d.pop("stac_version")
@@ -616,6 +659,7 @@ class Collection(Catalog):
             summaries=summaries,
             href=href,
             catalog_type=catalog_type,
+            assets=assets,
         )
 
         for link in links:
@@ -626,10 +670,6 @@ class Collection(Catalog):
             if link["rel"] != pystac.RelType.SELF or href is None:
                 collection.add_link(Link.from_dict(link))
 
-        if assets is not None:
-            for asset_key, asset_dict in assets.items():
-                collection.add_asset(asset_key, Asset.from_dict(asset_dict))
-
         if root:
             collection.set_root(root)
 
