@@ -1,9 +1,5 @@
-"""Implements the Raster extension.
+"""Implements the :stac-ext:`Raster Extension <raster>`."""
 
-https://github.com/stac-extensions/raster
-"""
-
-import enum
 from typing import Any, Dict, Iterable, List, Optional, Union
 
 import pystac
@@ -12,19 +8,19 @@ from pystac.extensions.base import (
     PropertiesExtension,
     SummariesExtension,
 )
-from pystac.utils import get_opt, get_required, map_opt
+from pystac.utils import StringEnum, get_opt, get_required, map_opt
 
-SCHEMA_URI = "https://stac-extensions.github.io/raster/v1.0.0/schema.json"
+SCHEMA_URI = "https://stac-extensions.github.io/raster/v1.1.0/schema.json"
 
 BANDS_PROP = "raster:bands"
 
 
-class Sampling(str, enum.Enum):
+class Sampling(StringEnum):
     AREA = "area"
     POINT = "point"
 
 
-class DataType(str, enum.Enum):
+class DataType(StringEnum):
     INT8 = "int8"
     INT16 = "int16"
     INT32 = "int32"
@@ -43,12 +39,20 @@ class DataType(str, enum.Enum):
     OTHER = "other"
 
 
+class NoDataStrings(StringEnum):
+    INF = "inf"
+    NINF = "-inf"
+    NAN = "nan"
+
+
 class Statistics:
     """Represents statistics information attached to a band in the raster extension.
 
     Use Statistics.create to create a new Statistics instance.
     """
 
+    properties: Dict[str, Any]
+
     def __init__(self, properties: Dict[str, Optional[float]]) -> None:
         self.properties = properties
 
@@ -209,6 +213,8 @@ class Histogram:
     Use Band.create to create a new Band.
     """
 
+    properties: Dict[str, Any]
+
     def __init__(self, properties: Dict[str, Any]) -> None:
         self.properties = properties
 
@@ -343,12 +349,14 @@ class RasterBand:
     Use Band.create to create a new Band.
     """
 
+    properties: Dict[str, Any]
+
     def __init__(self, properties: Dict[str, Any]) -> None:
         self.properties = properties
 
     def apply(
         self,
-        nodata: Optional[float] = None,
+        nodata: Optional[Union[float, NoDataStrings]] = None,
         sampling: Optional[Sampling] = None,
         data_type: Optional[DataType] = None,
         bits_per_sample: Optional[float] = None,
@@ -368,8 +376,8 @@ class RasterBand:
                 assumed to represent a sampling over the region of the pixel or a point
                 sample at the center of the pixel.
             data_type :The data type of the band.
-                One of the data types as described in
-                <https://github.com/stac-extensions/raster/#data-types>.
+                One of the data types as described in the
+                :stac-ext:`Raster Data Types <raster/#data-types> docs`.
             bits_per_sample : The actual number of bits used for this band.
                 Normally only present when the number of bits is non-standard for the
                 datatype, such as when a 1 bit TIFF is represented as byte
@@ -398,7 +406,7 @@ class RasterBand:
     @classmethod
     def create(
         cls,
-        nodata: Optional[float] = None,
+        nodata: Optional[Union[float, NoDataStrings]] = None,
         sampling: Optional[Sampling] = None,
         data_type: Optional[DataType] = None,
         bits_per_sample: Optional[float] = None,
@@ -418,8 +426,8 @@ class RasterBand:
                 assumed to represent a sampling over the region of the pixel or a point
                 sample at the center of the pixel.
             data_type :The data type of the band.
-                One of the data types as described in
-                <https://github.com/stac-extensions/raster/#data-types>.
+                One of the data types as described in the
+                :stac-ext:`Raster Data Types <raster/#data-types> docs`.
             bits_per_sample : The actual number of bits used for this band.
                 Normally only present when the number of bits is non-standard for the
                 datatype, such as when a 1 bit TIFF is represented as byte
@@ -450,7 +458,7 @@ class RasterBand:
         return b
 
     @property
-    def nodata(self) -> Optional[float]:
+    def nodata(self) -> Optional[Union[float, NoDataStrings]]:
         """Get or sets the nodata pixel value
 
         Returns:
@@ -459,7 +467,7 @@ class RasterBand:
         return self.properties.get("nodata")
 
     @nodata.setter
-    def nodata(self, v: Optional[float]) -> None:
+    def nodata(self, v: Optional[Union[float, NoDataStrings]]) -> None:
         if v is not None:
             self.properties["nodata"] = v
         else:
