@@ -1,4 +1,4 @@
-import sys
+from copy import deepcopy
 import numbers
 from enum import Enum
 from functools import lru_cache
@@ -12,17 +12,13 @@ from typing import (
     Generic,
     List,
     Optional,
+    Protocol,
     Union,
     TypeVar,
     Iterable,
     TYPE_CHECKING,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Protocol
-else:
-    from typing_extensions import Protocol
-
 if TYPE_CHECKING:
     from pystac.item import Item as Item_Type
     from pystac.collection import Collection as Collection_Type
@@ -58,6 +54,9 @@ T = TypeVar("T", bound=Union[_Comparable_x, _Comparable_other])
 
 
 class RangeSummary(Generic[T]):
+    minimum: T
+    maximum: T
+
     def __init__(self, minimum: T, maximum: T):
         self.minimum = minimum
         self.maximum = maximum
@@ -116,6 +115,8 @@ class Summarizer:
         If no file is passed, a default one will be used.
     """
 
+    summaryfields: Dict[str, SummaryStrategy]
+
     def __init__(self, fields: Optional[str] = None):
         fieldspath = fields or FIELDS_JSON_URL
         try:
@@ -132,7 +133,7 @@ class Summarizer:
         self._set_field_definitions(jsonfields)
 
     def _set_field_definitions(self, fields: Dict[str, Any]) -> None:
-        self.summaryfields: Dict[str, SummaryStrategy] = {}
+        self.summaryfields = {}
         for name, desc in fields["metadata"].items():
             if isinstance(desc, dict):
                 strategy_value = desc.get("summary", True)
@@ -194,16 +195,24 @@ DEFAULT_MAXCOUNT = 25
 
 
 class Summaries:
+    _summaries: Dict[str, Any]
+
+    lists: Dict[str, List[Any]]
+    other: Dict[str, Any]
+    ranges: Dict[str, RangeSummary[Any]]
+    schemas: Dict[str, Dict[str, Any]]
+    maxcount: int
+
     def __init__(
         self, summaries: Dict[str, Any], maxcount: int = DEFAULT_MAXCOUNT
     ) -> None:
         self._summaries = summaries
         self.maxcount = maxcount
 
-        self.lists: Dict[str, List[Any]] = {}
-        self.ranges: Dict[str, RangeSummary[Any]] = {}
-        self.schemas: Dict[str, Dict[str, Any]] = {}
-        self.other: Dict[str, Any] = {}
+        self.lists = {}
+        self.ranges = {}
+        self.schemas = {}
+        self.other = {}
 
         for prop_key, summary in summaries.items():
             self.add(prop_key, summary)
@@ -274,6 +283,21 @@ class Summaries:
             any(self.lists) or any(self.ranges) or any(self.schemas) or any(self.other)
         )
 
+    def clone(self) -> "Summaries":
+        """Clones this object.
+
+        Returns:
+            Summaries: The clone of this object
+        """
+        summaries = Summaries(
+            summaries=deepcopy(self._summaries), maxcount=self.maxcount
+        )
+        summaries.lists = deepcopy(self.lists)
+        summaries.other = deepcopy(self.other)
+        summaries.ranges = deepcopy(self.ranges)
+        summaries.schemas = deepcopy(self.schemas)
+        return summaries
+
     def to_dict(self) -> Dict[str, Any]:
         return {
             **{k: v for k, v in self.lists.items() if len(v) < self.maxcount},
